<?php

namespace Featured\Featured\Providers;

use Illuminate\Support\ServiceProvider;

class FeaturedServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'featured');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'featured');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('featured.featured', function ($app) {
            return $this->app->make('Featured\Featured\Featured');
        });

                // Bind 1 to repository
        $this->app->bind(
            'Featured\Featured\Interfaces\1RepositoryInterface',
            \Featured\Featured\Repositories\Eloquent\1Repository::class
        );

        $this->app->register(\Featured\Featured\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Featured\Featured\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['featured.featured'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('featured/featured.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/featured')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/featured')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
